Exec { timeout => 300 }

package{'nrpe':
    ensure => present,
    before => Class['nagios_configs']
}

file{'/etc/nagios/nrpe.cfg':
    ensure => 'present',
    mode => '0644',
    owner => 'nagios',
    group => 'nagios',
    require => Package['nrpe'],
}

class nagios_configs(){
    file_line{'allowed_hosts':
        path => '/etc/nagios/nrpe.cfg',
        match => 'allowed_hosts=',
        line => 'allowed_hosts=10.35.160.137',
    }

    # 5 minute load average
    file_line{'load5':
        path => '/etc/nagios/nrpe.cfg',
        match => 'command\[load5\]=',
        line => 'command[load5]=cut /proc/loadavg -f 1 -d " "',
    }

    # disk used on /var
    file_line{'df_var':
        path => '/etc/nagios/nrpe.cfg',
        match => "command\[df_var\]=",
        line => "command[df_var]=df /var/ | sed -re 's/.* ([0-9]+)%.*/\\1/' | grep -E '^[0-9]'",
    }
}
class{'nagios_configs':
    notify => Service['nrpe'],
}

service{'nrpe':
    ensure => running,
    enable => true,
    hasstatus => true,
}
# Create firewall rules to allow only the FIREWALL_ALLOWED
# hosts that need to connect via FIREWALL_PORTS
# using FIREWALL_CHAIN

packstack::firewall {'nagios_nrpe':
  host => '10.35.160.137',
  service_name => 'nagios-nrpe',
  chain => 'INPUT',
  ports => 5666,
  proto => 'tcp',
}
